# OIDCProxyHeaderReplace

The initial header name that will be replaced by the new name.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**old_name** | **str** | The header name that will be replaced. The match is case insensitive. | 
**new_name** | **str** | The header name to be replaced in a case sensitive manner. | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


